#
# spec file for package avalon-framework
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           avalon-framework
Version:        4.3
Release:        7.2
Summary:        Java components interfaces
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://avalon.apache.org/
#Source0:        http://archive.apache.org/dist/excalibur/avalon-framework/source/%{name}-api-%{version}-src.tar.gz
#Source1:        http://archive.apache.org/dist/excalibur/avalon-framework/source/%{name}-impl-%{version}-src.tar.gz
Source0:        %{name}-api-%{version}-src.tar.gz
Source1:        %{name}-impl-%{version}-src.tar.gz
Patch0:         0001-Port-build-script-to-Maven-3.patch
Patch1:         %{name}-manifest.patch
BuildRequires:  ant
BuildRequires:  avalon-logkit
BuildRequires:  commons-logging
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  reload4j
BuildArch:      noarch

%description
The Avalon framework consists of interfaces that define relationships
between commonly used application components, best-of-practice pattern
enforcements, and several lightweight convenience implementations of the
generic components.
What that means is that we define the central interface Component. We
also define the relationship (contract) a component has with peers,
ancestors and children.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
Provides:       %{name}-manual = %{version}-%{release}
Obsoletes:      %{name}-manual < %{version}-%{release}

%description javadoc
API documentation for %{name}.

%prep
%setup -q -cT -a 0 -a 1
%autopatch -p1

%build
pushd %{name}-api-%{version}
  mkdir -p target/lib
  build-jar-repository -s target/lib avalon-logkit
  ant -Dant.build.javac.source=8 -Dant.build.javac.target=8 dist
popd
pushd %{name}-impl-%{version}
  mkdir -p target/lib
  build-jar-repository -s target/lib avalon-logkit reload4j commons-logging
  cp ../%{name}-api-%{version}/target/*.jar target/lib/
  ant -Dant.build.javac.source=8 -Dant.build.javac.target=8 dist
popd

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 %{name}-api-%{version}/dist/%{name}-api-%{version}.jar %{buildroot}%{_javadir}/%{name}-api.jar
install -pm 0644 %{name}-impl-%{version}/dist/%{name}-impl-%{version}.jar %{buildroot}%{_javadir}/%{name}-impl.jar
(cd %{buildroot}%{_javadir} && ln -s %{name}-impl.jar %{name}.jar)
# poms
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{name}-api-%{version}/project.xml %{buildroot}%{_mavenpomdir}/%{name}-api.pom
%add_maven_depmap %{name}-api.pom %{name}-api.jar -a org.apache.avalon.framework:avalon-framework-api
%{mvn_install_pom} %{name}-impl-%{version}/project.xml %{buildroot}%{_mavenpomdir}/%{name}-impl.pom
%add_maven_depmap %{name}-impl.pom %{name}-impl.jar -a "org.apache.avalon.framework:avalon-framework-impl","avalon-framework:avalon-framework"
# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr %{name}-api-%{version}/dist/docs/api %{buildroot}%{_javadocdir}/%{name}/api
cp -pr %{name}-impl-%{version}/dist/docs/api %{buildroot}%{_javadocdir}/%{name}/impl
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%{_javadir}/%{name}.jar
%license avalon-framework-api-4.3/LICENSE.txt
%license avalon-framework-api-4.3/NOTICE.txt

%files javadoc
%{_javadocdir}/%{name}
%license avalon-framework-api-4.3/LICENSE.txt
%license avalon-framework-api-4.3/NOTICE.txt

%changelog
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Spec file cleanup
* Mon Jul 15 2024 Fridrich Strba <fstrba@suse.com>
- Add alias for avalon-framework:avalon-framework and point it to
  the avalon-framework:avalon-framework-impl artifact.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Rather use %%setup/%%autopatch: autosetup does not handle the
  decompression of additional sources and applying patches in the
  correct order for this package.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against log4j12 compatibility package
* Thu Apr  4 2019 Fridrich Strba <fstrba@suse.com>
- Do not require optional dependencies
* Mon Jan 21 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to 4.3
  * Two source packages avalon-framework-api-4.3 and
    avalon-framework-impl-4.3 buildable both with ant
  * Make javadoc subpackage provide the manual subpackage, since
    the manual content is basically a javadoc for api
- Added patches:
  * 0001-Port-build-script-to-Maven-3.patch
    + convert the project.xml files in both sources to a valid
    maven 3 pom files.
  * avalon-framework-manifest.patch
    + Add Bundle-SymbolicName attributes to both jar files
- Removed patch:
  * avalon-framework-target.patch
    + not needed with this version
* Wed Dec  5 2018 Fridrich Strba <fstrba@suse.com>
- Add maven pom files
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Fri Sep 15 2017 fstrba@suse.com
- Specify java source and target level 1.6 in order to allow build
  with jdk9
- Clean spec file a fix rpmlint warning
* Tue Jul  8 2014 tchvatal@suse.com
- Cleanup with spec-cleaner do not use brp disabling.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed Mar 20 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Jan 28 2013 mvyskocil@suse.com
- provide compat symlinks in /usr/share/java/excalibur
  part of a fix fo bnc#800694
* Sun Dec 18 2011 nlminhtl@gmail.com
- Package avalon-framework 4.1.4 (last one don't need maven) for openSUSE
- Fixing the license tag
